<?php
/**
 * Dizibiz functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Dizibiz
 */

if (!defined('_S_VERSION')) {
    // Replace the version number of the theme on each release.
    define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function dizibiz_setup()
{
    /*
        * Make theme available for translation.
        * Translations can be filed in the /languages/ directory.
        * If you're building a theme based on Dizibiz, use a find and replace
        * to change 'dizibiz' to the name of your theme in all the template files.
        */
    load_theme_textdomain('dizibiz', get_template_directory() . '/languages');

    // Add default posts and comments RSS feed links to head.
    add_theme_support('automatic-feed-links');

    /*
        * Let WordPress manage the document title.
        * By adding theme support, we declare that this theme does not use a
        * hard-coded <title> tag in the document head, and expect WordPress to
        * provide it for us.
        */
    add_theme_support('title-tag');

    /*
        * Enable support for Post Thumbnails on posts and pages.
        *
        * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
        */
    add_theme_support('post-thumbnails');

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus(
        array(
            'top-menu' => esc_html__('Top Menu', 'dizibiz'),
            'primary-menu' => esc_html__('Primary Menu', 'dizibiz'),
            'social-menu' => esc_html__('Social Menu', 'dizibiz'),
            'footer-menu' => esc_html__('Footer Menu', 'dizibiz'),
        )
    );

    /*
        * Switch default core markup for search form, comment form, and comments
        * to output valid HTML5.
        */
    add_theme_support(
        'html5',
        array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
        )
    );

    // Set up the WordPress core custom background feature.
    add_theme_support(
        'custom-background',
        apply_filters(
            'dizibiz_custom_background_args',
            array(
                'default-color' => 'ffffff',
                'default-image' => '',
            )
        )
    );

    // Add post-formats support.
    add_theme_support(
        'post-formats',
        array(
            'link',
            'aside',
            'gallery',
            'image',
            'quote',
            'status',
            'video',
            'audio',
            'chat',
        )
    );

    // Add theme support for selective refresh for widgets.
    add_theme_support('customize-selective-refresh-widgets');

    /**
     * Add support for core custom logo.
     *
     * @link https://codex.wordpress.org/Theme_Logo
     */
    add_theme_support(
        'custom-logo',
        array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        )
    );

    add_theme_support('align-wide');
    add_theme_support('responsive-embeds');
    add_theme_support('wp-block-styles');
}

add_action('after_setup_theme', 'dizibiz_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function dizibiz_content_width()
{
    $GLOBALS['content_width'] = apply_filters('dizibiz_content_width', 640);
}

add_action('after_setup_theme', 'dizibiz_content_width', 0);

/**
 *  Minor header styles/scripts that needs to run before other styles/scripts
 */
function dizibiz_head_scripts()
{
    ?>
    <script type="text/javascript">
        let storageKey = 'theme-preference';

        let getColorPreference = function () {
            if (localStorage.getItem(storageKey))
                return localStorage.getItem(storageKey)
            else
                return window.matchMedia('(prefers-color-scheme: dark)').matches
                    ? 'dark'
                    : 'light'
        }

        let theme = {
            value: getColorPreference()
        };

        let setPreference = function () {
            localStorage.setItem(storageKey, theme.value);
            reflectPreference();
        }

        let reflectPreference = function () {
            document.firstElementChild.setAttribute("data-theme", theme.value);
            document.querySelector("#theme-toggle-mode-button")?.setAttribute("aria-label", theme.value);
        }

        // set early so no page flashes / CSS is made aware
        reflectPreference();

        window.addEventListener('load', function () {
            reflectPreference();
            let toggleBtn = document.querySelector("#theme-toggle-mode-button");
            if (toggleBtn) {
                toggleBtn.addEventListener("click", function () {
                    theme.value = theme.value === 'light' ? 'dark' : 'light';
                    setPreference();
                });
            }
        });

        // sync with system changes
        window
            .matchMedia('(prefers-color-scheme: dark)')
            .addEventListener('change', ({matches: isDark}) => {
                theme.value = isDark ? 'dark' : 'light';
                setPreference();
            });
    </script>
    <style type="text/css">
        .svg-icon-colormode > :is(.moon, .sun, .sun-beams) {
            transform-origin: center center;
        }

        .svg-icon-colormode > :is(.moon, .sun) {
            fill: #000;
        }

        .svg-icon-colormode > .sun-beams {
            stroke: #000;
            stroke-width: 2px;
        }

        [data-theme="dark"] .svg-icon-colormode > .sun {
            transform: scale(1.75);
        }

        [data-theme="dark"] .svg-icon-colormode > .sun-beams {
            opacity: 0;
        }

        [data-theme="dark"] .svg-icon-colormode > .moon > circle {
            transform: translate(-7px);
        }

        @supports (cx: 1) {
            [data-theme="dark"] .svg-icon-colormode > .moon > circle {
                transform: translate(0);
                cx: 17;
            }
        }

        @media (prefers-reduced-motion: no-preference) {
            .svg-icon-colormode > .sun {
                transition: transform 0.5s cubic-bezier(0.5, 1.25, 0.75, 1.25);
            }

            .svg-icon-colormode > .sun-beams {
                transition: transform 0.5s cubic-bezier(0.5, 1.5, 0.75, 1.25), opacity 0.5s cubic-bezier(0.25, 0, 0.3, 1);
            }

            .svg-icon-colormode .moon > circle {
                transition: transform 0.25s cubic-bezier(0, 0, 0, 1);
            }

            @supports (cx: 1) {
                .svg-icon-colormode .moon > circle {
                    transition: cx 0.25s cubic-bezier(0, 0, 0, 1);
                }
            }
            [data-theme="dark"] .svg-icon-colormode > .sun {
                transform: scale(1.75);
                transition-timing-function: cubic-bezier(0.25, 0, 0.3, 1);
                transition-duration: 0.25s;
            }

            [data-theme="dark"] .svg-icon-colormode > .sun-beams {
                transform: rotate(-25deg);
                transition-duration: 0.15s;
            }

            [data-theme="dark"] .svg-icon-colormode > .moon > circle {
                transition-delay: 0.25s;
                transition-duration: 0.5s;
            }
        }

        .theme-button-colormode {
            padding: 0;
            inline-size: 2rem;
            block-size: 2rem;
            aspect-ratio: 1;
            cursor: pointer;
            touch-action: manipulation;
        }
        .theme-button-colormode > svg {
            inline-size: 100%;
            block-size: 100%;
            stroke-linecap: round;
        }

        [data-theme="dark"] .svg-icon-colormode > :is(.moon, .sun) {
            fill: #fff;
        }

        [data-theme="dark"] .svg-icon-colormode > .sun-beams {
            stroke: #fff;
            stroke-width: 2px;
        }
    </style>
    <?php
}

add_action('wp_head', 'dizibiz_head_scripts');

/**
 * Enqueue scripts and styles.
 */
function dizibiz_scripts()
{

    $min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

    $fonts_url = dizibiz_fonts_url();
    if ($fonts_url) {

        require_once get_theme_file_path('inc/webfont/class-theme-webfont-loader.php');
        wp_enqueue_style(
            'dizibiz-google-fonts',
            wptt_get_webfont_url($fonts_url),
            array(),
            _S_VERSION
        );
    }

    wp_enqueue_style('animate', get_template_directory_uri() . '/assets/css/animate' . $min . '.css', array(), _S_VERSION);


    wp_enqueue_style('glightbox', get_template_directory_uri() . '/assets/css/glightbox' . $min . '.css', array(), _S_VERSION);
    wp_enqueue_script( 'glightbox-script', get_template_directory_uri() . '/assets/js/glightbox' . $min . '.js', array(), _S_VERSION, true );

    wp_enqueue_style('swiper', get_template_directory_uri() . '/assets/css/swiper-bundle' . $min . '.css', array(), _S_VERSION);
    wp_enqueue_script( 'swiper-script', get_template_directory_uri() . '/assets/js/swiper-bundle' . $min . '.js', array(), _S_VERSION, true );

    wp_enqueue_style('dizibiz-style', get_stylesheet_uri(), array(), _S_VERSION);
    wp_style_add_data('dizibiz-style', 'rtl', 'replace');
    wp_add_inline_style('dizibiz-style', dizibiz_get_inline_css());


    if (dizibiz_get_option('enable_dark_mode')) {
        wp_enqueue_style('dizibiz-night-style', get_template_directory_uri() . '/assets/css/dark-mode.css', array(), _S_VERSION);
        wp_add_inline_style('dizibiz-night-style', dizibiz_get_dark_mode_inline_css());
    }

    wp_enqueue_script('dizibiz-script', get_template_directory_uri() . '/assets/js/script.js', array('jquery'), _S_VERSION, true);


    // Ajax Load Posts Scripts
    $pagination_type = dizibiz_get_option('pagination_type');
    if ('ajax_load_on_click' == $pagination_type || 'ajax_load_on_scroll' == $pagination_type):
        wp_enqueue_script('dizibiz-load-posts', get_template_directory_uri() . '/assets/js/pagination.js', array(), _S_VERSION, true);
        // Localized variables
        global $wp_query;
        wp_localize_script('dizibiz-load-posts', 'DizibizVars', array(
            'nonce' => wp_create_nonce('dizibiz-load-posts-nonce'),
            'ajaxurl' => admin_url('admin-ajax.php'),
            'query_vars' => json_encode($wp_query->query_vars)
        ));
    endif;


    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}

add_action('wp_enqueue_scripts', 'dizibiz_scripts');


add_action('init', function() {
  $dizibiz_icon_base_url = basename($_SERVER['REQUEST_URI']);
  if ( $dizibiz_icon_base_url == 'twp-dizibiz-svg-icon-set' ) {
     // load the file if exists
     $load = locate_template('/inc/twp-svg.php', true);
     if ($load) {
        exit(); // just exit if template was found and loaded
     }
  }
});


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom functions for this theme.
 */
require get_template_directory() . '/inc/custom-functions.php';

/**
 * Custom Widgets and sidebars for this theme.
 */
require get_template_directory() . '/inc/widgets/init.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if (class_exists('WooCommerce')) {
    require get_template_directory() . '/inc/woocommerce.php';
}
/**
 */
require get_template_directory() . '/classes/body-class.php';

/**
 * Load SVG Icons
 */
require get_template_directory() . '/classes/class-svg-icons.php';

/**
 * Admin
 */
require get_template_directory() . '/inc/admin.php';

/**
 * Load dynamic styles
 */

include(get_template_directory() . '/inc/dynamic-styles.php');


include(get_template_directory() . '/inc/pagination.php');

add_filter('themeinwp_enable_demo_import_compatiblity', 'dizibiz_demo_import_filter_apply');

if (!function_exists('dizibiz_demo_import_filter_apply')):

    function dizibiz_demo_import_filter_apply()
    {

        return true;

    }

endif;